#Fontchooser for python GUI or tkinter

To install module : pip install rvfont\
Latest version = "1.0.3"

#Example code:

from rvfont.rvfontchooser import FontDialog\
get_font=FontDialog()\
print(get_font)

It will give output like:
{'font': 'Arial', 'size': 10, 'weight': 'normal', 'slant': 'roman', 'underline': True, 'strike': False}

Developed by \
Ravikirana B\
Email: ravikiranb36@gmail.com